/* ide-xml-symbol-tree.h
 *
 * Copyright 2017 Sébastien Lafargue <slafargue@gnome.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include <libide-code.h>
#include "ide-xml-symbol-node.h"

G_BEGIN_DECLS

#define IDE_TYPE_XML_SYMBOL_TREE (ide_xml_symbol_tree_get_type())

G_DECLARE_FINAL_TYPE (IdeXmlSymbolTree, ide_xml_symbol_tree, IDE, XML_SYMBOL_TREE, GObject)

IdeXmlSymbolTree *ide_xml_symbol_tree_new (IdeXmlSymbolNode *root_node);

G_END_DECLS
